Changelog
=========

0.3.0 (2013-06-07)
------------------

- Added template tag helpers ``linkTo`` and ``ember`` (thanks to Paulo Scardine)
- Upgraded to Ember.js 1.0.0-RC.5
- Upgraded to Ember Data 0.13
- Upgraded to latest Ember Data Tastypie Adapter (9db4b9a)
- Upgraded to Handlebars 1.0.0
- Python 2.6 support


0.2.0 (2013-05-09)
------------------

- Depends on and extend django.js
- Upgraded to Handlebars 1.0.0.rc.3
- Upgraded to Ember.js 1.0.0-RC.3-279-g41b62d7
- Upgraded to latest Ember Data git version (e33b544)
- Make jquery optionnal for ``{% ember_full_js %}`` and ``{% emberpie_js %}``
- Support query string in ``TastypieAdapater`` (thanks to Peter Sutton/dj-foxxy)
- Provide both minified and unminified versions (triggered by ``settings.DEBUG``)
- Python 3 compatible
- Django 1.5 compatible


0.1 (2012-08-06)
----------------

- Initial release
